==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/coletor/__openerp__.py <==
# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2013 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz[at]siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2013, Creative Commons
# Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
#
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

{
    'name': 'Modulo coletor',
    'description': """
Modulo coletor
==============

Modulo coletor para **entrada** e **manipulacao** de dados a partir de um coletor de dados.

Permite:
--------

* Entrada de dados diretamente a partir de um coletor de dados

""",
    'category': 'Estoque',
    'summary': 'Coletor de dados',
    'version': '7.0.21.12.14',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['adm'],
    'data': [
        # ________________________ Grupos e acessos __________________________
        'security/coletor_security.xml',
        'security/ir.model.access.csv',

        # Visao
        'views/usuario_coletor_view.xml',
        'views/modulo_coletor_view.xml',
        'views/action.xml',
        'views/menu.xml',
    ],
    'license': 'Other proprietary',
    'installable': True,
    'application': True,
    'active': False,
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/coletor/__openerp__.py <==
# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2013 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz[at]siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2013, Creative Commons
# Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
#
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

{
    'name': 'Modulo coletor',
    'description': """
Modulo coletor
==============

Modulo coletor para **entrada** e **manipulacao** de dados a partir de um coletor de dados.

Permite:
--------

* Entrada de dados diretamente a partir de um coletor de dados

""",
    'category': 'Estoque',
    'summary': 'Coletor de dados',
    'version': '7.0.2310.2',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['adm'],
    'data': [
        # ________________________ Grupos e acessos __________________________
        'security/coletor_security.xml',
        'security/ir.model.access.csv',

        # Visao
        'views/usuario_coletor_view.xml',
        'views/modulo_coletor_view.xml',
        'views/action.xml',
        'views/menu.xml',
    ],
    'license': 'Other proprietary',
    'installable': True,
    'application': True,
    'active': False,
}
